==> qmmp-1.1.7.tar.bz2: qmmp-1.1.7/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>ファイルを追加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="44"/>
        <source>Up</source>
        <translation>親階層へ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="47"/>
        <location filename="../qmmpfiledialog.ui" line="60"/>
        <location filename="../qmmpfiledialog.ui" line="79"/>
        <location filename="../qmmpfiledialog.ui" line="104"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="57"/>
        <source>List view</source>
        <translation>一覧表示</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="76"/>
        <source>Detailed view</source>
        <translation>詳細表示</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="101"/>
        <source>Close dialog on add</source>
        <translation>追加を終えるとダイアログも閉じる</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="184"/>
        <source>File name:</source>
        <translation>ファイル名:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="200"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="207"/>
        <source>Files of type:</source>
        <translation>この種のファイル:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="233"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="69"/>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>Qmmp File Dialog</source>
        <translation>QMMP ファイルダイアログ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="78"/>
        <source>About Qmmp File Dialog</source>
        <translation>QMMP ファイルダイアログについて</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>制作:
Владимир Кузнецов (Vladimir Kuznetsov) &lt;vovanec@gmail.com&gt;
Илья Котов (Ilya Kotov) &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="83"/>
        <source>Some code is copied from the Qt library</source>
        <translation>コードの一部に Qt ライブラリのソースを流用しています</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="250"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="263"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="277"/>
        <source>Directories</source>
        <translation>ディレクトリ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="446"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 は既にあります。
置き換えますか。</translation>
    </message>
</context>
</TS>

==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/FileDialogs/QmmpFileDialog/translations/qmmp_file_dialog_plugin_ja.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ja_JP">
<context>
    <name>QmmpFileDialog</name>
    <message>
        <location filename="../qmmpfiledialog.ui" line="14"/>
        <source>Add Files</source>
        <translation>ファイルを追加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="177"/>
        <source>Up</source>
        <translation>親階層へ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="180"/>
        <location filename="../qmmpfiledialog.ui" line="193"/>
        <location filename="../qmmpfiledialog.ui" line="212"/>
        <location filename="../qmmpfiledialog.ui" line="237"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="190"/>
        <source>List view</source>
        <translation>一覧表示</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="209"/>
        <source>Detailed view</source>
        <translation>詳細表示</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="234"/>
        <source>Close dialog on add</source>
        <translation>追加を終えるとダイアログも閉じる</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="106"/>
        <source>File name:</source>
        <translation>ファイル名:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="122"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="129"/>
        <source>Files of type:</source>
        <translation>この種のファイル:</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.ui" line="155"/>
        <source>Close</source>
        <translation>閉じる</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogFactory</name>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="70"/>
        <location filename="../qmmpfiledialog.cpp" line="80"/>
        <source>Qmmp File Dialog</source>
        <translation>QMMP ファイルダイアログ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="79"/>
        <source>About Qmmp File Dialog</source>
        <translation>QMMP ファイルダイアログについて</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="81"/>
        <source>Written by:
Vladimir Kuznetsov &lt;vovanec@gmail.com&gt;
Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>制作:
Владимир Кузнецов (Vladimir Kuznetsov) &lt;vovanec@gmail.com&gt;
Илья Котов (Ilya Kotov) &lt;forkotov02@ya.ru&gt;</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialog.cpp" line="84"/>
        <source>Some code is copied from the Qt library</source>
        <translation>コードの一部に Qt ライブラリのソースを流用しています</translation>
    </message>
</context>
<context>
    <name>QmmpFileDialogImpl</name>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="262"/>
        <source>Add</source>
        <translation>追加</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="275"/>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="289"/>
        <source>Directories</source>
        <translation>ディレクトリ</translation>
    </message>
    <message>
        <location filename="../qmmpfiledialogimpl.cpp" line="476"/>
        <source>%1 already exists.
Do you want to replace it?</source>
        <translation>%1 は既にあります。
置き換えますか。</translation>
    </message>
</context>
</TS>
